#![allow(clippy::module_inception)]
#![allow(clippy::upper_case_acronyms)]
#![allow(clippy::large_enum_variant)]
#![allow(clippy::wrong_self_convention)]
#![allow(clippy::should_implement_trait)]
#![allow(clippy::blacklisted_name)]
#![allow(clippy::vec_init_then_push)]
#![allow(rustdoc::bare_urls)]
//! <p>Amazon Augmented AI (Amazon A2I) adds the benefit of human judgment to any machine learning
//! application. When an AI application can't evaluate data with a high degree of confidence,
//! human reviewers can take over. This human review is called a human review workflow. To create
//! and start a human review workflow, you need three resources: a <i>worker task
//! template</i>, a <i>flow definition</i>, and a <i>human
//! loop</i>.</p>
//! <p>For information about these resources and prerequisites for using Amazon A2I, see <a href="https://docs.aws.amazon.com/sagemaker/latest/dg/a2i-getting-started.html">Get Started with
//! Amazon Augmented AI</a> in the Amazon SageMaker Developer Guide.</p>
//! <p>This API reference includes information about API actions and data types that you can use
//! to interact with Amazon A2I programmatically. Use this guide to:</p>
//! <ul>
//! <li>
//! <p>Start a human loop with the <code>StartHumanLoop</code> operation when using
//! Amazon A2I with a <i>custom task type</i>. To learn more about the
//! difference between custom and built-in task types, see <a href="https://docs.aws.amazon.com/sagemaker/latest/dg/a2i-task-types-general.html">Use Task Types </a>. To learn
//! how to start a human loop using this API, see <a href="https://docs.aws.amazon.com/sagemaker/latest/dg/a2i-start-human-loop.html#a2i-instructions-starthumanloop">Create and Start a Human Loop for a Custom Task Type </a> in the
//! Amazon SageMaker Developer Guide.</p>
//! </li>
//! <li>
//! <p>Manage your human loops. You can list all human loops that you have created, describe
//! individual human loops, and stop and delete human loops. To learn more, see <a href="https://docs.aws.amazon.com/sagemaker/latest/dg/a2i-monitor-humanloop-results.html">Monitor and Manage Your Human Loop </a> in the Amazon SageMaker Developer Guide.</p>
//! </li>
//! </ul>
//! <p>Amazon A2I integrates APIs from various AWS services to create and start human review
//! workflows for those services. To learn how Amazon A2I uses these APIs, see <a href="https://docs.aws.amazon.com/sagemaker/latest/dg/a2i-api-references.html">Use APIs in
//! Amazon A2I</a> in the Amazon SageMaker Developer Guide.</p>

// Code generated by software.amazon.smithy.rust.codegen.smithy-rs. DO NOT EDIT.
pub use error_meta::Error;

pub use config::Config;

mod aws_endpoint;
#[cfg(feature = "client")]
pub mod client;
pub mod config;
pub mod error;
mod error_meta;
pub mod input;
mod json_deser;
mod json_errors;
mod json_ser;
pub mod model;
mod no_credentials;
pub mod operation;
mod operation_deser;
mod operation_ser;
pub mod output;
pub static PKG_VERSION: &str = env!("CARGO_PKG_VERSION");
pub use smithy_http::byte_stream::ByteStream;
pub use smithy_http::result::SdkError;
pub use smithy_types::Blob;
static API_METADATA: aws_http::user_agent::ApiMetadata =
    aws_http::user_agent::ApiMetadata::new("sagemakera2iruntime", PKG_VERSION);
pub use aws_types::region::Region;
pub use aws_types::Credentials;
#[cfg(feature = "client")]
pub use client::Client;
pub use smithy_http::endpoint::Endpoint;
pub use smithy_types::retry::RetryConfig;
